@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import R from 'ramda'
@@ -25,18 +26,23 @@ import {
   addIngressNodeInfo,
   setClusterStatus
 } from '../../utils/diagram-helpers'
+import { showArgoApplicationSetLink } from '../../utils/diagram-helpers-argo'
 import msgs from '../../../../../nls/platform.properties'
+import { kubeNaming } from './titles'
 
 const resName = 'resource.name'
 
 export const getNodeDetails = (node, updatedNode, activeFilters) => {
   const details = []
   if (node) {
-    const { type, specs } = node
-    const { labels = [] } = node
+    const { type, specs, labels = [] } = node
+
+    // for argo apps with application sets
+    showArgoApplicationSetLink(node, details)
 
     //if resource has a row number add deployable yaml
     createDeployableYamlLink(node, details)
+
     details.push({
       type: 'spacer'
     })
@@ -110,7 +116,9 @@ export const getNodeDetails = (node, updatedNode, activeFilters) => {
 }
 
 function addK8Details(node, updatedNode, details, activeFilters) {
-  const { clusterName, type, layout = {} } = node
+  const { clusterName, type, layout = {}, specs } = node
+  const { isDesign } = specs
+  let labels
   const { type: ltype } = layout
 
   // not all resources have a namespace
@@ -119,7 +127,7 @@ function addK8Details(node, updatedNode, details, activeFilters) {
   if (node && R.pathOr('', ['specs', 'pulse'])(node) !== 'orange') {
     const kindModel = _.get(node, `specs.${type}Model`, {})
     let computedNSList = []
-    Object.values(kindModel).forEach(item => {
+    _.flatten(Object.values(kindModel)).forEach(item => {
       computedNSList = R.union(computedNSList, [item.namespace])
     })
 
@@ -139,13 +147,18 @@ function addK8Details(node, updatedNode, details, activeFilters) {
   ]
     ? 'apps.open-cluster-management.io/git-path'
     : 'apps.open-cluster-management.io/github-path'
+  const gitTagAnnotation = 'apps.open-cluster-management.io/git-tag'
+  const gitCommitAnnotation =
+    'apps.open-cluster-management.io/git-desired-commit'
+  const reconcileRateAnnotation =
+    'apps.open-cluster-management.io/reconcile-rate'
 
   const apiVersion = _.get(node, 'specs.raw.apiVersion', '')
   // the main stuff
   const mainDetails = [
     {
       labelKey: 'resource.type',
-      value: ltype || type
+      value: kubeNaming(ltype) || kubeNaming(type)
     },
     {
       labelKey: 'resource.api.version',
@@ -189,17 +202,36 @@ function addK8Details(node, updatedNode, details, activeFilters) {
       'raw.spec.version'
     )
   )
-  //
 
-  addPropertyToList(
-    mainDetails,
-    getNodePropery(
-      node,
-      ['specs', 'raw', 'metadata', 'labels'],
-      'raw.spec.metadata.label',
-      'No labels'
+  //
+  if (!isDesign && isDesign !== undefined) {
+    const resourceModel = _.get(specs, `${type}Model`)
+    if (resourceModel) {
+      // get first item in the object as all should have the same labels
+      const resourceLabels =
+        Object.keys(resourceModel).length > 0
+          ? resourceModel[Object.keys(resourceModel)[0]][0].label
+          : undefined
+      labels = resourceLabels ? resourceLabels.replace('; ', ',') : 'No labels'
+    } else {
+      labels = 'No labels'
+    }
+
+    addPropertyToList(mainDetails, {
+      labelKey: 'raw.spec.metadata.label',
+      value: labels
+    })
+  } else {
+    addPropertyToList(
+      mainDetails,
+      getNodePropery(
+        node,
+        ['specs', 'raw', 'metadata', 'labels'],
+        'raw.spec.metadata.label',
+        'No labels'
+      )
     )
-  )
+  }
 
   addPropertyToList(
     mainDetails,
@@ -260,6 +292,16 @@ function addK8Details(node, updatedNode, details, activeFilters) {
     getNodePropery(node, ['specs', 'raw', 'spec', 'source'], 'raw.spec.source')
   )
 
+  //argo cd app status
+  addPropertyToList(
+    mainDetails,
+    getNodePropery(
+      node,
+      ['specs', 'raw', 'status', 'health', 'status'],
+      'raw.status.health.status'
+    )
+  )
+
   addPropertyToList(
     mainDetails,
     getNodePropery(
@@ -315,6 +357,39 @@ function addK8Details(node, updatedNode, details, activeFilters) {
     )
   )
 
+  if (nodeAnnotations[gitTagAnnotation]) {
+    addPropertyToList(
+      mainDetails,
+      getNodePropery(
+        node,
+        ['specs', 'raw', 'metadata', 'annotations', gitTagAnnotation],
+        'spec.subscr.annotations.gitTag'
+      )
+    )
+  }
+
+  if (nodeAnnotations[gitCommitAnnotation]) {
+    addPropertyToList(
+      mainDetails,
+      getNodePropery(
+        node,
+        ['specs', 'raw', 'metadata', 'annotations', gitCommitAnnotation],
+        'spec.subscr.annotations.gitCommit'
+      )
+    )
+  }
+
+  if (nodeAnnotations[reconcileRateAnnotation]) {
+    addPropertyToList(
+      mainDetails,
+      getNodePropery(
+        node,
+        ['specs', 'raw', 'metadata', 'annotations', reconcileRateAnnotation],
+        'spec.subscr.annotations.reconcileRate'
+      )
+    )
+  }
+
   //PR specific
   addPropertyToList(
     mainDetails,
