@@ -1,15 +1,19 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
+ *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+
 'use strict'
 
 import msgs from '../../../../../nls/platform.properties'
 import _ from 'lodash'
+import R from 'ramda'
 import { getClusterName } from '../../utils/diagram-helpers-utils'
 
 const clusterLabels = 'cluster.metadata.labels'
@@ -134,19 +138,6 @@ export const getAllFilters = (
       .sort()
   }
 
-  // if lots of unknown types, assign some unknown types to spare shapes
-  if (unknownTypes.length > 3 && availableTypes.length < 3) {
-    const set = new Set(unknownTypes)
-    sorted.filter(a => set.has(a)).some((a, idx) => {
-      const spareKey = `spare${idx + 1}`
-      typeToShapeMap[a] = typeToShapeMap[spareKey]
-      availableTypes.push(a)
-      otherTypeFilters = otherTypeFilters.filter(b => a !== b)
-      delete typeToShapeMap[spareKey]
-      return idx >= 5 // only 5 spares
-    })
-  }
-
   // if there are still other shapes, add to available
   if (otherTypeFilters.length > 0) {
     availableTypes = _.union(availableTypes, ['other'])
@@ -417,7 +408,7 @@ export const addAvailableRelationshipFilters = (
           switch (filterType) {
           case 'hostIPs':
             if (podStatus && Object.keys(podStatus).length > 0) {
-              Object.values(podStatus).forEach(pod => {
+              _.flatten(Object.values(podStatus)).forEach(pod => {
                 filter.availableSet.add(pod.hostIP)
               })
             }
@@ -638,8 +629,9 @@ export const filterRelationshipNodes = (nodes, activeFilters) => {
       if (podStatus) {
         hasHostIps = Array.from(hostIPs).some(ip => {
           return (
-            Object.values(podStatus).find(pod => pod.hostIP === ip) !==
-            undefined
+            _.flatten(_.flatten(Object.values(podStatus))).find(
+              pod => pod.hostIP === ip
+            ) !== undefined
           )
         })
       }
@@ -652,8 +644,11 @@ export const filterRelationshipNodes = (nodes, activeFilters) => {
     // filter by cluster name
     let hasClustername = true
     if (notDesignNode(nodeType) && clusterNames.size !== 0) {
-      const clusterName = getClusterName(id)
-      hasClustername = clusterNames.has(clusterName)
+      hasClustername = false
+      const clusterNamesArray = R.split(',', getClusterName(id, node) || [])
+      clusterNamesArray.forEach(clsN => {
+        hasClustername = hasClustername || clusterNames.has(clsN)
+      })
     }
 
     const result =
