@@ -1,9 +1,8 @@
-/** *****************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 /// <reference types="cypress" />
+import { checkExistingUrls } from "./resources.js";
 
 export const pageLoader = {
   shouldExist: () =>
@@ -44,24 +43,28 @@ export const selectTimeWindow = (timeWindow, key = 0) => {
       .click({ force: true });
     selectDate(date, key);
 
-    cy
-      .get(".bx--combo-box.config-timezone-combo-box.bx--list-box")
-      .within($timezone => {
-        cy.get("[type='button']").click();
-        cy
-          .get(".bx--list-box__menu-item:first-of-type", {
-            timeout: 30 * 1000
-          })
-          .click();
-      });
+    cy.get(".pf-c-select.config-timezone-combo-box").within($timezone => {
+      cy.get("[type='button']").click();
+      cy
+        .get(".pf-c-select__menu-item:first", {
+          timeout: 30 * 1000
+        })
+        .click();
+    });
 
     if (hours) {
+      const group = key != 0 ? `grp${key}` : "";
       hours.forEach((interval, idx) => {
-        cy.get(`#start-time-${idx}`).type(interval.start);
-        cy.get(`#end-time-${idx}`).type(interval.end);
+        const startTime = `#start-time-${idx}-timeWindow${group}-input`;
+        const endTime = `#end-time-${idx}-timeWindow${group}-input`;
+        cy.get(startTime).type(interval.start);
+        cy.get(endTime).type(interval.end);
 
         if (idx < hours.length - 1) {
-          cy.get(".add-time-btn", { timeout: 10 * 1000 }).click();
+          cy
+            .get(".add-time-btn", { timeout: 10 * 1000 })
+            .scrollIntoView()
+            .click({ force: true });
         }
       });
     }
@@ -77,7 +80,7 @@ export const selectTimeWindow = (timeWindow, key = 0) => {
   }
 };
 
-export const submitSave = successState => {
+export const submitSave = (successState, redirectString) => {
   modal.shouldNotBeDisabled();
   modal.clickSubmit();
   cy
@@ -86,18 +89,20 @@ export const submitSave = successState => {
 
   if (successState) {
     notification.shouldExist("success");
-    cy
-      .location("pathname", { timeout: 10 * 1000 })
-      .should("include", `${name}`);
+    if (redirectString) {
+      cy
+        .location("pathname", { timeout: 10 * 1000 })
+        .should("include", `${redirectString}`);
+    }
   } else {
-    notification.shouldExist("error");
+    notification.shouldExist("danger");
     cy.log("Verify Save button is disabled");
     modal.shouldBeDisabled();
   }
 };
 
 const getPFTableRowSelector = key =>
-  `[data-ouia-component-type="PF4/TableRow"][data-ouia-component-id="${key}"]`;
+  `[data-ouia-component-type="PF4/TableRow"][data-ouia-component-id='${key}']`;
 
 export const resourceTable = {
   getRow: function(name, key, timeout) {
@@ -105,8 +110,9 @@ export const resourceTable = {
       timeout: timeout || 30 * 1000
     });
   },
-  getCell: function(name) {
-    return cy.get(`td[data-label="${name}"]`);
+  getCell: function(name, index) {
+    const attribute = index ? `data-key=${index}` : `data-label="${name}"`;
+    return cy.get(`td[${attribute}]`, { timeout: 30 * 1000 });
   },
   rowShouldExist: function(name, key, timeout) {
     this.searchTable(name);
@@ -128,7 +134,8 @@ export const resourceTable = {
       .get(`${getPFTableRowSelector(key)} .pf-c-dropdown__toggle`, {
         timeout: 20 * 10000
       })
-      .click();
+      .scrollIntoView()
+      .click({ force: true });
   },
   getMenuButton: function(action) {
     return cy.contains("button", action, {
@@ -141,11 +148,6 @@ export const resourceTable = {
   }
 };
 
-export const secondaryHeader = {
-  clickPrimary: () => cy.get(".secondary-header-actions-primary").click(),
-  clickSecondary: () => cy.get(".secondary-header-actions-secondary").click()
-};
-
 export const noResource = {
   shouldExist: () =>
     cy
@@ -160,10 +162,9 @@ export const noResource = {
 };
 
 export const modal = {
-  shouldBeOpen: () =>
-    cy.get("#remove-resource-modal", { timeout: 20000 }).should("exist"),
-  shouldBeClosed: () =>
-    cy.get("#remove-resource-modal", { timeout: 20000 }).should("not.exist"),
+  shouldBeOpen: modalId => cy.get(modalId, { timeout: 20000 }).should("exist"),
+  shouldBeClosed: modalId =>
+    cy.get(modalId, { timeout: 20000 }).should("not.exist"),
   shouldBeVisible: () =>
     cy.get("#create-button-portal-id", { timeout: 20000 }).should("be.visible"),
   shouldNotBeVisible: () =>
@@ -172,15 +173,21 @@ export const modal = {
       .should("not.be.visible"),
   shouldNotBeDisabled: () =>
     cy
-      .get(".bx--btn.bx--btn--primary", { timeout: 20000 })
+      .get(".pf-c-button.pf-m-primary", {
+        timeout: 20000
+      })
       .should("not.be.disabled"),
   shouldBeDisabled: () =>
     cy
-      .get(".bx--btn.bx--btn--primary", { timeout: 20000 })
+      .get(".pf-c-button.pf-m-primary", {
+        timeout: 20000
+      })
       .should("be.disabled"),
   clickSubmit: () =>
     cy
-      .get(".bx--btn.bx--btn--primary", { timeout: 20000 })
+      .get(".pf-c-button.pf-m-primary", {
+        timeout: 20000
+      })
       .click({ force: true }),
   clickResources: () =>
     cy.get("#remove-app-resources", { timeout: 20000 }).click({ force: true }),
@@ -188,28 +195,22 @@ export const modal = {
     cy.get(".pf-m-danger", { timeout: 20000 }).click({ force: true }),
   clickPrimary: () =>
     cy
-      .get(".bx--btn.bx--btn--sm.bx--btn--primary, .pf-c-button.pf-m-primary", {
+      .get(".pf-c-button.pf-m-primary", {
         timeout: 20 * 1000
       })
       .then($el => {
         Cypress.dom.isDetached($el); // false
       })
       .click({ force: true }),
-  clickSecondary: () =>
-    cy
-      .get(".bx--btn.bx--btn--sm.bx--btn--secondary", { timeout: 20000 })
-      .click(),
   confirmAction: text => cy.get("#confirm-action").type(text)
 };
 
 export const notification = {
   shouldExist: type =>
-    cy
-      .get(`.bx--inline-notification[kind="${type}"]`, { timeout: 10 * 1000 })
-      .should("exist"),
+    cy.get(`.pf-c-alert.pf-m-${type}`, { timeout: 10 * 1000 }).should("exist"),
   shouldNotExist: type =>
     cy
-      .get(`.bx--inline-notification[kind="${type}"]`, { timeout: 5 * 1000 })
+      .get(`.pf-c-alert.pf-m-${type}`, { timeout: 5 * 1000 })
       .should("not.exist")
 };
 
@@ -228,7 +229,7 @@ export const selectClusterDeployment = (deployment, clusterName, key) => {
         onlineClusterID: "#online-cluster-only-checkbox",
         uniqueClusterID: "#clusterSelector-checkbox-clusterSelector",
         existingClusterID: "#existingrule-checkbox",
-        existingRuleComboID: "#placementrulecombo",
+        existingRuleComboID: "#placementrulecombo-label",
         labelNameID: "#labelName-0-clusterSelector",
         labelValueID: "#labelValue-0-clusterSelector"
       },
@@ -254,9 +255,9 @@ export const selectClusterDeployment = (deployment, clusterName, key) => {
         .trigger("mouseover", { force: true });
 
       cy.get(existingRuleComboID).within($rules => {
-        cy.get("[type='button']").click();
+        cy.get(".pf-c-select__toggle-button").click();
         cy
-          .get(".bx--list-box__menu-item:first-of-type", {
+          .get(".pf-c-select__menu-item:first", {
             timeout: 30 * 1000
           })
           .click();
@@ -312,7 +313,11 @@ export const selectMatchingLabel = (cluster, key) => {
     key
   );
   const { labelName, labelValue } = matchingLabelCSS;
-  cy.get(labelName).type("name"), cy.get(labelValue).type(cluster);
+  cy
+    .get(labelName)
+    .scrollIntoView({ offset: { top: -100, left: 0 } })
+    .type("name"),
+    cy.get(labelValue).type(cluster);
 };
 
 export const verifyYamlTemplate = text => {
@@ -517,6 +522,8 @@ export const verifyApplicationData = (name, data, opType) => {
             prSectionId,
             existingRuleId,
             reconcileKey,
+            commitHashKey,
+            tagKey,
             matchingLabelId,
             onlineId,
             localClusterId
@@ -526,6 +533,8 @@ export const verifyApplicationData = (name, data, opType) => {
               prSectionId: "#clustersection-select-clusters-to-deploy-to",
               existingRuleId: "#existingrule-checkbox",
               reconcileKey: "#gitReconcileOption",
+              commitHashKey: "#gitDesiredCommit",
+              tagKey: "#gitTag",
               matchingLabelId: "#clusterSelector-checkbox-clusterSelector",
               onlineId: "#online-cluster-only-checkbox",
               localClusterId: "#local-cluster-checkbox"
@@ -536,17 +545,68 @@ export const verifyApplicationData = (name, data, opType) => {
           cy.get(channelSectionId).click();
           if (data.type == "git") {
             cy.log(`Verify Git reconcile option for ${name}`);
-            item.gitReconcileOption &&
-              cy
-                .get(reconcileKey)
-                .invoke("val")
-                .should("eq", item.gitReconcileOption);
+            if (!item.disableAutoReconcileOption) {
+              item.gitReconcileOption &&
+                cy
+                  .get(reconcileKey)
+                  .invoke("val")
+                  .should("eq", item.gitReconcileOption);
 
-            !item.gitReconcileOption &&
+              !item.gitReconcileOption &&
+                cy
+                  .get(reconcileKey)
+                  .invoke("val")
+                  .should("eq", "merge"); //default is merge
+            } else {
+              cy.log(
+                `Git reconcile option for ${name} is hidden because auto-reconcilation is disabled`
+              );
+            }
+
+            cy.log(`Verify Git commit hash and tag for ${name}`);
+            item.commitHash &&
               cy
-                .get(reconcileKey)
+                .get(commitHashKey)
                 .invoke("val")
-                .should("eq", "merge"); //default is merge
+                .should("eq", item.commitHash);
+            item.tag &&
+              cy
+                .get(tagKey)
+                .invoke("val")
+                .should("eq", item.tag);
+          }
+
+          if (data.type == "git" || data.type == "helm") {
+            const { reconcileRate, subReconcileRate } = indexedCSS(
+              {
+                reconcileRate: `#${data.type}ReconcileRate`,
+                subReconcileRate: `#${data.type}SubReconcileRate`
+              },
+              key
+            );
+
+            cy.log(`Verify reconcile rate for ${name}`);
+            item.repositoryReconcileRate &&
+              cy
+                .get(reconcileRate)
+                .invoke("val")
+                .should("eq", item.repositoryReconcileRate);
+
+            !item.repositoryReconcileRate &&
+              cy
+                .get(reconcileRate)
+                .invoke("val")
+                .should("eq", "medium"); //default is medium
+
+            cy.log(`Verify auto reconcilation option for ${name}`);
+            item.disableAutoReconcileOption &&
+              cy
+                .get(subReconcileRate, { timeout: 20 * 1000 })
+                .should("be.checked");
+            !item.disableAutoReconcileOption &&
+              cy
+                .get(subReconcileRate, { timeout: 20 * 1000 })
+                .should("not.be.checked");
           }
 
           const { deployment } = item;
@@ -629,141 +689,174 @@ const convertTimeFormat = time => {
   }
 };
 
+export const validateSyncFunction = (type, opType) => {
+  if (opType === "create") {
+    if (type === "git") {
+      // wait for sync button to display
+      cy
+        .get("#sync-app", { timeout: 50 * 1000 })
+        .scrollIntoView()
+        .click();
+      modal.shouldBeOpen("#sync-resource-modal");
+      cy.get(".pf-c-empty-state", { timeout: 100 * 1000 }).should("not.exist");
+      modal.clickSubmit();
+      modal.shouldBeClosed("#sync-resource-modal");
+      notification.shouldExist("success");
+    } else if (type === "argo") {
+      cy.log(`verify sync button doesn't exist for Argo apps`);
+      cy.get("#sync-app", { timeout: 10 * 1000 }).should("not.exist");
+    }
+  } else {
+    //ignore this
+    return;
+  }
+};
+
 export const validateSubscriptionDetails = (name, data, type, opType) => {
   if (opType == "delete") {
     //ignore this
     return;
   }
-  // as soon as details button is enabled we can proceed
-  cy
-    .get("[data-test-subscription-details=true]", { timeout: 50 * 1000 })
-    .scrollIntoView()
-    .click();
-  for (const [key, itemConfig] of Object.entries(data.config)) {
-    let value = itemConfig;
-    if (opType == "add") {
-      value = key == 0 ? data.config[1] : data.new[0]; // here we assume first subscription was removed by the delete test and then added a new one
-    }
 
-    // some subscriptions might not have time window
-    const type = value.timeWindow ? value.timeWindow.type : "active"; //if not defined is always active
-    cy.log(`Validate subscriptions cards for ${name} key=${key}`);
-
-    // Get "Repository resource" info
-    let repoInfo = value.url;
-    if (value.branch && value.branch.length > 0) {
-      repoInfo = `${repoInfo}Branch:${value.branch}`;
-    }
-    if (value.path && value.path.length > 0) {
-      repoInfo = `${repoInfo}Path:${value.path}`;
-    }
-
-    // Get "Time window" info
-    let timeWindowInfo = {};
-    if (value.timeWindow) {
-      timeWindowInfo["date"] = `Days of the week${value.timeWindow.date.join(
-        ", "
-      )}`;
-
-      if (value.timeWindow.hours) {
-        let timeRangeString = "";
-        value.timeWindow.hours.forEach((range, i) => {
-          timeRangeString =
-            `${timeRangeString}${convertTimeFormat(
-              range.start
-            )} - ${convertTimeFormat(range.end)}` +
-            `${i < value.timeWindow.hours.length - 1 ? ", " : ""}`;
-        });
-        timeWindowInfo["hours"] = `Time range${timeRangeString}`;
+  if (type !== "argo") {
+    // as soon as details button is enabled we can proceed
+    cy
+      .get("[data-test-subscription-details=true]", { timeout: 50 * 1000 })
+      .scrollIntoView()
+      .click();
+    for (const [key, itemConfig] of Object.entries(data.config)) {
+      let value = itemConfig;
+      if (opType == "add") {
+        value = key == 0 ? data.config[1] : data.new[0]; // here we assume first subscription was removed by the delete test and then added a new one
       }
-    }
-    const keywords = {
-      blockinterval: "Blocked",
-      activeinterval: "Active",
-      active: "Set time window"
-    };
 
-    // 1. Check "Repository resource" button and popover
-    cy
-      .get(".overview-cards-subs-section", { timeout: 120 * 1000 })
-      .children()
-      .eq(key)
-      .within($subcards => {
-        cy.log("Validate subscription repository info");
-        let repositoryText =
-          data.type === "objectstore"
-            ? "Object storage"
-            : data.type === "helm" ? "Helm" : "Git";
+      // some subscriptions might not have time window
+      const type = value.timeWindow ? value.timeWindow.type : "active"; //if not defined is always active
+      cy.log(`Validate subscriptions cards for ${name} key=${key}`);
 
-        //get repository popup info
-        cy
-          .get(".add-right-border", { timeout: 20 * 1000 })
-          .eq(1)
-          .within($repo => {
-            cy
-              .get(".pf-c-label__content", { timeout: 120 * 1000 })
-              .invoke("text")
-              .should("include", repositoryText);
+      // Get "Repository resource" info
+      let repoInfo = value.url;
+      if (value.branch && value.branch.length > 0) {
+        repoInfo = `${repoInfo}Branch:${value.branch}`;
+      }
+      if (value.path && value.path.length > 0) {
+        repoInfo = `${repoInfo}Path:${value.path}`;
+      }
+
+      // Get "Time window" info
+      let timeWindowInfo = {};
+      if (value.timeWindow) {
+        timeWindowInfo["date"] = `Days of the week${value.timeWindow.date.join(
+          ", "
+        )}`;
+
+        if (value.timeWindow.hours) {
+          let timeRangeString = "";
+          value.timeWindow.hours.forEach((range, i) => {
+            timeRangeString =
+              `${timeRangeString}${convertTimeFormat(
+                range.start
+              )} - ${convertTimeFormat(range.end)}` +
+              `${i < value.timeWindow.hours.length - 1 ? ", " : ""}`;
           });
-
-        cy.log("Validate Repository popup");
-        let repoInfo = value.url;
-        if (value.branch && value.branch.length > 0) {
-          repoInfo = `${repoInfo}Branch:${value.branch}`;
+          timeWindowInfo["hours"] = `Time range${timeRangeString}`;
         }
-        if (value.path && value.path.length > 0) {
-          repoInfo = `${repoInfo}Path:${value.path}`;
-        }
-        cy
-          .get(".pf-c-label")
-          .first()
-          .click({ force: true });
-      });
-    // Validate info in popover
-    cy
-      .get(".channel-labels-popover-content .channel-entry", {
-        timeout: 20 * 1000
-      })
-      .invoke("text")
-      .should("include", repoInfo);
-    cy
-      .get(".subs-icon")
-      .first()
-      .click(); // Close any popovers
+      }
+      const keywords = {
+        blockinterval: "Blocked",
+        activeinterval: "Active",
+        active: "Set time window"
+      };
 
-    // 2. Check "Time window" button and popover
-    cy
-      .get(".overview-cards-subs-section", { timeout: 20 * 1000 })
-      .children()
-      .eq(key)
-      .within($subcards => {
-        cy.log(`Validate time window for subscription is ${keywords[type]}`);
-        type == "active"
-          ? cy
-              .get(".set-time-window-link", { timeout: 20 * 1000 })
-              .contains(keywords[type])
-          : cy
-              .get(".timeWindow-status-icon", { timeout: 20 * 1000 })
-              .contains(keywords[type].toLowerCase());
-
-        if (type !== "active") {
-          cy.log("Validate time window popup");
-          cy
-            .get(".timeWindow-status-icon", { timeout: 20 * 1000 })
-            .click({ force: true });
-        }
-      });
-    // Validate info in popover
-    if (type !== "active") {
+      // 1. Check "Repository resource" button and popover
       cy
-        .get(".timeWindow-labels-popover-content", { timeout: 20 * 1000 })
+        .get(".overview-cards-subs-section", { timeout: 120 * 1000 })
+        .children()
+        .eq(key)
+        .within($subcards => {
+          cy.log("Validate subscription repository info");
+          let repositoryText =
+            data.type === "objectstore"
+              ? "Object storage"
+              : data.type === "helm" ? "Helm" : "Git";
+
+          //get repository popup info
+          cy
+            .get(".add-right-border", { timeout: 20 * 1000 })
+            .eq(1)
+            .within($repo => {
+              cy
+                .get(".pf-c-label__content", { timeout: 120 * 1000 })
+                .invoke("text")
+                .should("include", repositoryText);
+            });
+
+          cy.log("Validate Repository popup");
+          let repoInfo = value.url;
+          if (value.branch && value.branch.length > 0) {
+            repoInfo = `${repoInfo}Branch:${value.branch}`;
+          }
+          if (value.path && value.path.length > 0) {
+            repoInfo = `${repoInfo}Path:${value.path}`;
+          }
+          cy
+            .get(".pf-c-label")
+            .first()
+            .click({ force: true });
+        });
+      // Validate info in popover
+      cy
+        .get(".channel-labels-popover-content .channel-entry", {
+          timeout: 20 * 1000
+        })
         .invoke("text")
-        .should("include", "Edit time window");
+        .should("include", repoInfo);
       cy
         .get(".subs-icon")
         .first()
         .click(); // Close any popovers
+
+      // 2. Check "Time window" button and popover
+      cy
+        .get(".overview-cards-subs-section", { timeout: 20 * 1000 })
+        .children()
+        .eq(key)
+        .within($subcards => {
+          cy.log(`Validate time window for subscription is ${keywords[type]}`);
+          type == "active"
+            ? cy
+                .get(".set-time-window-link", { timeout: 20 * 1000 })
+                .contains(keywords[type])
+            : cy
+                .get(".timeWindow-status-icon", { timeout: 20 * 1000 })
+                .contains(keywords[type].toLowerCase());
+
+          if (type !== "active") {
+            cy.log("Validate time window popup");
+            cy
+              .get(".timeWindow-status-icon", { timeout: 20 * 1000 })
+              .click({ force: true });
+          }
+        });
+      // Validate info in popover
+      if (type !== "active") {
+        cy
+          .get(".timeWindow-labels-popover-content", { timeout: 20 * 1000 })
+          .invoke("text")
+          .should("include", "Edit time window");
+        cy
+          .get(".subs-icon")
+          .first()
+          .click(); // Close any popovers
+      }
     }
+  } else {
+    cy.log(
+      `${name} is an argoCD application. Show subscription details should be hidden.`
+    );
+    cy
+      .get("[data-test-subscription-details=true]", { timeout: 50 * 1000 })
+      .should("not.exist");
   }
 };
 
@@ -775,18 +868,79 @@ const saveErrorShouldNotExist = () => {
   notification.shouldNotExist("error", { timeout: 2 * 1000 }); //save error goes away
 };
 
-//verify https://github.com/stolostron/backlog/issues/7080
+//verify https://github.com/open-cluster-management/backlog/issues/7080
 export const testDefect7080 = () => {
   //click all clusters option
   cy.log("Test defect 7080 - check all online clusters option");
-  cy.get("#online-cluster-only-checkbox").click({ force: true });
+  cy
+    .get("#online-cluster-only-checkbox", { timeout: 50 * 1000 })
+    .click({ force: true });
 
   //click local cluster only
   cy.log("Test defect 7080 - verify local cluster option can be checked");
-  cy.get("#local-cluster-checkbox").click({ force: true });
+  cy
+    .get("#local-cluster-checkbox", { timeout: 50 * 1000 })
+    .click({ force: true });
 
   cy.log("Test defect 7080 - now go back to default option");
-  cy.get("#local-cluster-checkbox").click({ force: true });
+  cy
+    .get("#local-cluster-checkbox", { timeout: 50 * 1000 })
+    .click({ force: true });
+};
+
+//verify that as we select the git api, we get the branch and path information
+export const testGitApiInput = data => {
+  const { config } = data;
+  const { url, branch, path, username, token } = config[0];
+  const gitCss = {
+    gitUrl: "#githubURL",
+    gitUser: "#githubUser",
+    gitKey: "#githubAccessId",
+    gitBranch: "#githubBranch",
+    gitPath: "#githubPath",
+    merge: "#gitReconcileOption",
+    insecureSkipVerify: "#gitInsecureSkipVerify"
+  };
+
+  const { gitUrl, gitUser, gitKey, gitBranch, gitPath } = gitCss;
+
+  cy.visit("/multicloud/applications");
+  // wait for create button to be enabled
+  cy.get("[data-test-create-application=true]", { timeout: 50 * 1000 }).click();
+  cy.get(".pf-c-title").should("exist");
+
+  cy.log("Select git url");
+  cy
+    .get("#git", { timeout: 20 * 1000 })
+    .click({ force: true })
+    .trigger("mouseover");
+
+  checkExistingUrls(gitUser, username, gitKey, token, gitUrl, url);
+
+  // check branch and path info shows up
+  cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
+  if (url.indexOf("github.com") >= 0) {
+    cy.get(gitBranch, { timeout: 50 * 1000 }).click();
+    cy.contains(".tf--list-box__menu-item", new RegExp(`^${branch}$`)).click();
+  } else {
+    cy.log("Nothing to test");
+    cy
+      .get(gitBranch, { timeout: 50 * 1000 })
+      .type(branch, { timeout: 50 * 1000 })
+      .blur();
+  }
+
+  cy.wait(1000);
+  cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
+  if (url.indexOf("github.com") >= 0) {
+    cy.get(gitPath, { timeout: 20 * 1000 }).click();
+    cy.contains(".tf--list-box__menu-item", new RegExp(`^${path}$`)).click();
+  } else {
+    cy
+      .get(gitPath, { timeout: 20 * 1000 })
+      .type(path, { timeout: 30 * 1000 })
+      .blur();
+  }
 };
 
 export const testInvalidApplicationInput = () => {
@@ -797,44 +951,44 @@ export const testInvalidApplicationInput = () => {
   cy.visit("/multicloud/applications");
   // wait for create button to be enabled
   cy.get("[data-test-create-application=true]", { timeout: 50 * 1000 }).click();
-  cy.get(".bx--detail-page-header-title-container").should("exist");
+  cy.get(".pf-c-title").should("exist");
 
   //enter a valid ns
   cy
-    .get("#namespace", { timeout: 50 * 1000 })
+    .get("#emanspace", { timeout: 50 * 1000 })
     .click()
     .clear()
     .type("default")
     .blur();
 
   cy.log("Test invalid name");
-  cy.get("#name", { timeout: 50 * 1000 }).type(invalidValue);
-  cy.get("#name-error-msg").should("exist");
+  cy.get("#eman", { timeout: 50 * 1000 }).type(invalidValue);
+  cy.get("#eman-helper").should("exist");
 
   submitSave(false); //test save error
 
   cy
-    .get("#name", { timeout: 50 * 1000 })
+    .get("#eman", { timeout: 50 * 1000 })
     .clear()
     .type(validValue);
-  cy.get("#name-error-msg").should("not.exist");
+  cy.get("#eman-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
 
   cy.log("Test invalid namespace");
   cy
-    .get("#namespace", { timeout: 50 * 1000 })
+    .get("#emanspace", { timeout: 50 * 1000 })
     .type(invalidValue)
     .blur();
-  cy.get("[data-invalid=true]", { timeout: 2 * 1000 }).should("exist");
+  cy.get("#emanspace-helper").should("exist");
   submitSave(false); //test save error
 
   cy
-    .get("#namespace", { timeout: 50 * 1000 })
+    .get("#emanspace", { timeout: 50 * 1000 })
     .click()
     .clear()
     .type("default")
     .blur();
-  cy.get("[data-invalid=true]").should("not.exist");
+  cy.get("#emanspace-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
 
   cy.log("Test invalid git url");
@@ -845,16 +999,20 @@ export const testInvalidApplicationInput = () => {
 
   cy
     .get("#githubURL", { timeout: 20 * 1000 })
+    .scrollIntoView()
     .type(invalidValue)
     .blur();
 
   testDefect7080();
 
   //enter a valid deployment value
-  cy.get("#labelName-0-clusterSelector").type("label");
+  cy
+    .get("#labelName-0-clusterSelector")
+    .scrollIntoView()
+    .type("label");
   cy.get("#labelValue-0-clusterSelector").type("value");
 
-  cy.get("[data-invalid=true]").should("exist");
+  cy.get("#githubURL-helper").should("exist");
   cy.wait(1000);
   submitSave(false); //test save error
 
@@ -864,7 +1022,7 @@ export const testInvalidApplicationInput = () => {
     .clear()
     .type(validURL)
     .blur();
-  cy.get("[data-invalid=true]").should("not.exist");
+  cy.get("#githubURL-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
 
   cy
@@ -872,7 +1030,7 @@ export const testInvalidApplicationInput = () => {
     .trigger("mouseover")
     .type(invalidValue)
     .blur();
-  cy.get("[data-invalid=true]").should("exist");
+  cy.get("#githubBranch-helper").should("exist");
   cy.wait(2000);
 
   cy
@@ -880,18 +1038,20 @@ export const testInvalidApplicationInput = () => {
     .trigger("mouseover")
     .type(validValue)
     .blur();
-  cy.get("[data-invalid=true]").should("not.exist");
+  cy.get("#githubBranch-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
   cy.wait(2000);
 
   cy.log("Test invalid HELM url");
   cy
     .get("#git")
+    .last()
     .click()
     .trigger("mouseover");
 
   cy
     .get("#helm")
+    .last()
     .click()
     .trigger("mouseover");
 
@@ -900,11 +1060,14 @@ export const testInvalidApplicationInput = () => {
     .type(invalidValue)
     .blur();
   //enter a valid deployment value and a chart name
-  cy.get("#labelName-0-clusterSelector").type("label");
+  cy
+    .get("#labelName-0-clusterSelector")
+    .scrollIntoView()
+    .type("label");
   cy.get("#labelValue-0-clusterSelector").type("value");
   cy.get("#helmChartName").type("chartName");
 
-  cy.get("[data-invalid=true]").should("exist");
+  cy.get("#helmURL-helper").should("exist");
   cy.wait(1000);
   submitSave(false); //test save error
 
@@ -914,7 +1077,7 @@ export const testInvalidApplicationInput = () => {
     .clear()
     .type(validURL)
     .blur();
-  cy.get("[data-invalid=true]").should("not.exist");
+  cy.get("#helmURL-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
 
   cy.log("Test invalid object store url");
@@ -932,10 +1095,13 @@ export const testInvalidApplicationInput = () => {
     .type(invalidValue)
     .blur();
   //enter a valid deployment value
-  cy.get("#labelName-0-clusterSelector").type("label");
+  cy
+    .get("#labelName-0-clusterSelector")
+    .scrollIntoView()
+    .type("label");
   cy.get("#labelValue-0-clusterSelector").type("value");
 
-  cy.get("[data-invalid=true]").should("exist");
+  cy.get("#objectstoreURL-helper").should("exist");
   cy.wait(1000);
   submitSave(false); //test save error
 
@@ -945,7 +1111,7 @@ export const testInvalidApplicationInput = () => {
     .clear()
     .type(validURL)
     .blur();
-  cy.get("[data-invalid=true]").should("not.exist");
+  cy.get("#objectstoreURL-helper").should("not.exist");
   saveErrorShouldNotExist(); //save error goes away
 
   cy.log("Test invalid time window");
@@ -971,6 +1137,9 @@ export const indexedCSS = (cssMap, index) =>
           case "#channel-repository-types":
             selector = `#channelgrp${index}-repository-types`;
             break;
+          case "#placementrulecombo-label":
+            selector = `#placementrulecombogrp${index}-label`;
+            break;
           default:
             selector = `${cssMap[key]}grp${index}`;
             break;
@@ -984,7 +1153,27 @@ export const getNamespace = name => {
   return `${name}-ns`;
 };
 
-export const getResourceKey = (name, namespace) => `${namespace}/${name}`;
+export const getArgoGroupKey = (name, namespace, cluster, data) => {
+  if (data.applicationSet) {
+    return JSON.stringify({
+      applicationSet: data.applicationSet,
+      namespace,
+      cluster
+    });
+  } else if (data.groupedByResource) {
+    const config = data.config[0];
+    return JSON.stringify({
+      repoURL: config.url,
+      path: config.path,
+      chart: null,
+      targetRevision: config.branch || "HEAD"
+    });
+  }
+  return null;
+};
+
+export const getResourceKey = (name, namespace, cluster) =>
+  (cluster ? `${cluster}/` : "") + `${namespace}/${name}`;
 
 //validate all deployed nodes show up in the app topo
 export const validateDeployables = data => {
@@ -1010,17 +1199,42 @@ export const validateRbacAlert = () => {
     .should("eq", alertMessage);
 };
 
-export const validateDefect7696 = () => {
+export const validateDefect7696 = name => {
   cy.log(
     "verify defect 7696 - resources still show in topology view after moving from Editor tab to Overview"
   );
+  cy.visit(`/multicloud/applications/${name}-ns/${name}`);
+  cy.reload();
+  cy
+    .get(".search-query-card-loading", { timeout: 50 * 1000 })
+    .should("not.exist");
+  cy
+    .get(".pf-l-grid__item")
+    .first()
+    .contains(name);
 
   cy.log("Select Editor tab");
-  cy.get("#editor", { timeout: 20 * 1000 }).click({ force: true });
+  cy
+    .get(".pf-c-page__main-nav .pf-c-nav__list .pf-c-nav__item:nth-child(2)", {
+      timeout: 20 * 1000
+    })
+    .click();
 
   cy.log(
     "Verify defect 8055 - Temptifly 0.1.15 no longer shows yaml toggler for app-ui"
   );
+
+  cy
+    .intercept({
+      method: "POST", // Route all POST requests
+      url: `/multicloud/applications/graphql`
+    })
+    .as("graphql");
+  // as soon as edit button is shown we can proceed
+  cy.wait(["@graphql", "@graphql"], {
+    timeout: 50 * 1000
+  });
+
   cy.get("#edit-button-portal-id", { timeout: 20 * 1000 }).should("be.visible");
 
   cy.log("show YAML");
@@ -1034,7 +1248,11 @@ export const validateDefect7696 = () => {
   cy.log(
     "move back to topology view and check resources still show up - defect 7696"
   );
-  cy.get("#overview", { timeout: 20 * 1000 }).click({ force: true });
+  cy
+    .get(".pf-c-page__main-nav .pf-c-nav__list .pf-c-nav__item:nth-child(1)", {
+      timeout: 20 * 1000
+    })
+    .click();
 
   cy.log("Verify deployables show up");
   cy.get("#diagramShapes_pod", { timeout: 30 * 1000 }).should("exist");
